pub struct RedeemTicketsRequest {
pub address: Option<String>,
}Expand description
Request body for ticket redemption with optional fields.
JSON schema
{
"description": "Request body for ticket redemption with optional fields.",
"examples": [
{
"address": "0x188c4462b75e46f0c7262d7f48d182447b93a93c"
}
],
"type": "object",
"properties": {
"address": {
"description": "On-chain address of the counterparty whose incoming channel tickets to redeem.\nIf omitted, tickets in all channels are redeemed.",
"examples": [
"0x188c4462b75e46f0c7262d7f48d182447b93a93c"
],
"type": [
"string",
"null"
]
}
}
}Fields
address: Option<String>On-chain address of the counterparty whose incoming channel tickets to redeem. If omitted, tickets in all channels are redeemed.